@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,7 +29,7 @@ public:
     Q_REQUIRED_RESULT QString code(QWidget *) const override;
     Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
     Q_REQUIRED_RESULT QStringList needRequires(QWidget *parent) const override;
-    Q_REQUIRED_RESULT bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    void setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
     Q_REQUIRED_RESULT bool needCheckIfServerHasCapability() const override;
     Q_REQUIRED_RESULT QString serverNeedsCapability() const override;
     Q_REQUIRED_RESULT QString help() const override;
